<h1 align="center" style="border-bottom: none">
    <a href="https://mlflow.org/">
        <img alt="MLflow logo" src="assets/kortecx_readme.png" width="400" />
    </a>
</h1>
<h2 align="center" style="border-bottom: none">Executable intelligence Platform </h2>

Kortecx is an open-source zero-hassle library to generalize the training and finetuning LLMs at scale, synthesize and engineer data, and build Agentic AI solutions.

</div>

<div align="center">
   <div>
      <a href="https://kortecx.com/"><strong>Website</strong></a> ·
      <a href="https://kortecx.com/docs"><strong>Docs</strong></a> ·
      <a href="https://github.com/Kortecx/kortecx/issues/new/choose"><strong>Feature Request</strong></a> ·
      <a href="https://www.youtube.com/@executableintelligence"><strong>YouTube</strong></a>
   </div>
</div>
